Author: juha
Date: 2008-02-14 11:25:56 +0000 (Thu, 14 Feb 2008)
New Revision: 26610

Modified:
   xfcalendar/trunk/configure.in.in
   xfcalendar/trunk/src/appointment.c
Log:
 Fixed Bug 3841 - Appointment end time not updated when start time is changed
 By default Orage now uses duration, which eliminates this problem.
 End date is still not update automatically.
 Also added sound to be default alarm in addition to visible alarm.


Modified: xfcalendar/trunk/configure.in.in
===================================================================
--- xfcalendar/trunk/configure.in.in    2008-02-14 10:43:01 UTC (rev 26609)
+++ xfcalendar/trunk/configure.in.in    2008-02-14 11:25:56 UTC (rev 26610)
@@ -9,7 +9,7 @@
 dnl
 
 dnl Version information
-m4_define([orage_version], [4.5.12.6-svn])
+m4_define([orage_version], [4.5.12.7-svn])
 
 m4_define([gtk_minimum_version], [2.6.0])
 m4_define([xfce_minimum_version], [4.4.0])

Modified: xfcalendar/trunk/src/appointment.c
===================================================================
--- xfcalendar/trunk/src/appointment.c  2008-02-14 10:43:01 UTC (rev 26609)
+++ xfcalendar/trunk/src/appointment.c  2008-02-14 11:25:56 UTC (rev 26610)
@@ -1355,6 +1355,8 @@
             appt->start_tz_loc = g_strdup("floating");
         appt->end_tz_loc = g_strdup(appt->start_tz_loc);
         appt->duration = 30*60;
+        /* use duration by default for new appointments */
+        appt->use_duration = TRUE;
         g_sprintf(appt->completedtime,"%sT%02d%02d00"
                     , today, t->tm_hour, t->tm_min);
         appt->completed_tz_loc = g_strdup(appt->start_tz_loc);
@@ -1366,8 +1368,10 @@
         appt->soundrepeat_cnt = 500;
         appt->soundrepeat_len = 2;
 
         /* default alarm type is orage window */
         appt->display_alarm_orage = TRUE;
+        appt->sound_alarm = TRUE;
+        /* default sound file is set in fill_appt_window */
     }
     else if ((strcmp(action, "UPDATE") == 0) || (strcmp(action, "COPY") == 0)) 
@@ -1366,8 +1368,10 @@
         appt->soundrepeat_len = 2;
 
-        /* default alarm type is orage window */
+        /* default alarm type is orage window and sound */
         appt->display_alarm_orage = TRUE;
{
         /* par contains ical uid */

_______________________________________________
Xfce4-commits mailing list
Xfce4-commits@xfce.org
http://foo-projects.org/mailman/listinfo/xfce4-commits

Reply via email to